==> aws-cdk.aws-apigatewayv2-integrations-alpha-2.8.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpAlbIntegrationProps(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpNlbIntegrationProps(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpServiceDiscoveryIntegrationProps(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpLambdaIntegrationProps(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_WebSocketMockIntegration(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpUrlIntegration(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_WebSocketLambdaIntegration(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpLambdaIntegration(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpUrlIntegrationProps(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpPrivateIntegrationOptions(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpServiceDiscoveryIntegration(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpNlbIntegration(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpAlbIntegration(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpAlbIntegrationProps, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpNlbIntegrationProps, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpServiceDiscoveryIntegrationProps, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpLambdaIntegrationProps, _aws_cdk_aws_apigatewayv2_integrations_alpha_WebSocketMockIntegration, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpUrlIntegration, _aws_cdk_aws_apigatewayv2_integrations_alpha_WebSocketLambdaIntegration, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpLambdaIntegration, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpUrlIntegrationProps, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpPrivateIntegrationOptions, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpServiceDiscoveryIntegration, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpNlbIntegration, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpAlbIntegration };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-apigatewayv2-integrations-alpha-2.15.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpAlbIntegrationProps(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpNlbIntegrationProps(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpServiceDiscoveryIntegrationProps(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpLambdaIntegrationProps(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_WebSocketMockIntegration(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_WebSocketLambdaIntegration(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpUrlIntegration(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpLambdaIntegration(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpUrlIntegrationProps(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpPrivateIntegrationOptions(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpServiceDiscoveryIntegration(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpAlbIntegration(p) {
}
function _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpNlbIntegration(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpAlbIntegrationProps, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpNlbIntegrationProps, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpServiceDiscoveryIntegrationProps, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpLambdaIntegrationProps, _aws_cdk_aws_apigatewayv2_integrations_alpha_WebSocketMockIntegration, _aws_cdk_aws_apigatewayv2_integrations_alpha_WebSocketLambdaIntegration, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpUrlIntegration, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpLambdaIntegration, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpUrlIntegrationProps, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpPrivateIntegrationOptions, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpServiceDiscoveryIntegration, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpAlbIntegration, _aws_cdk_aws_apigatewayv2_integrations_alpha_HttpNlbIntegration };
module.exports.DeprecationError = DeprecationError;
